@@ -76,7 +76,7 @@
 /* Copy the first part of user declarations.  */
 
 /* Line 189 of yacc.c  */
-#line 1 "../../intl/plural.y"
+#line 1 "plural.y"
 
 /* Expression parsing for plural form selection.
    Copyright (C) 2000-2001, 2003 Free Software Foundation, Inc.
@@ -124,7 +124,7 @@
 
 
 /* Line 189 of yacc.c  */
-#line 128 "../../intl/plural.c"
+#line 128 "plural.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -173,7 +173,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 49 "../../intl/plural.y"
+#line 49 "plural.y"
 
   unsigned long int num;
   enum operator op;
@@ -182,7 +182,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 186 "../../intl/plural.c"
+#line 186 "plural.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -193,7 +193,7 @@ typedef union YYSTYPE
 /* Copy the second part of user declarations.  */
 
 /* Line 264 of yacc.c  */
-#line 55 "../../intl/plural.y"
+#line 55 "plural.y"
 
 /* Prototypes for local functions.  */
 static int yylex (YYSTYPE *lval, const char **pexp);
@@ -270,7 +270,7 @@ new_exp_3 (enum operator op, struct expression *bexp,
 
 
 /* Line 264 of yacc.c  */
-#line 274 "../../intl/plural.c"
+#line 274 "plural.c"
 
 #ifdef short
 # undef short
@@ -1473,7 +1473,7 @@ yyreduce:
         case 2:
 
 /* Line 1455 of yacc.c  */
-#line 151 "../../intl/plural.y"
+#line 151 "plural.y"
     {
 	    if ((yyvsp[(1) - (1)].exp) == NULL)
 	      YYABORT;
@@ -1484,7 +1484,7 @@ yyreduce:
   case 3:
 
 /* Line 1455 of yacc.c  */
-#line 159 "../../intl/plural.y"
+#line 159 "plural.y"
     {
 	    (yyval.exp) = new_exp_3 (qmop, (yyvsp[(1) - (5)].exp), (yyvsp[(3) - (5)].exp), (yyvsp[(5) - (5)].exp));
 	  }
@@ -1493,7 +1493,7 @@ yyreduce:
   case 4:
 
 /* Line 1455 of yacc.c  */
-#line 163 "../../intl/plural.y"
+#line 163 "plural.y"
     {
 	    (yyval.exp) = new_exp_2 (lor, (yyvsp[(1) - (3)].exp), (yyvsp[(3) - (3)].exp));
 	  }
@@ -1502,7 +1502,7 @@ yyreduce:
   case 5:
 
 /* Line 1455 of yacc.c  */
-#line 167 "../../intl/plural.y"
+#line 167 "plural.y"
     {
 	    (yyval.exp) = new_exp_2 (land, (yyvsp[(1) - (3)].exp), (yyvsp[(3) - (3)].exp));
 	  }
@@ -1511,7 +1511,7 @@ yyreduce:
   case 6:
 
 /* Line 1455 of yacc.c  */
-#line 171 "../../intl/plural.y"
+#line 171 "plural.y"
     {
 	    (yyval.exp) = new_exp_2 ((yyvsp[(2) - (3)].op), (yyvsp[(1) - (3)].exp), (yyvsp[(3) - (3)].exp));
 	  }
@@ -1520,7 +1520,7 @@ yyreduce:
   case 7:
 
 /* Line 1455 of yacc.c  */
-#line 175 "../../intl/plural.y"
+#line 175 "plural.y"
     {
 	    (yyval.exp) = new_exp_2 ((yyvsp[(2) - (3)].op), (yyvsp[(1) - (3)].exp), (yyvsp[(3) - (3)].exp));
 	  }
@@ -1529,7 +1529,7 @@ yyreduce:
   case 8:
 
 /* Line 1455 of yacc.c  */
-#line 179 "../../intl/plural.y"
+#line 179 "plural.y"
     {
 	    (yyval.exp) = new_exp_2 ((yyvsp[(2) - (3)].op), (yyvsp[(1) - (3)].exp), (yyvsp[(3) - (3)].exp));
 	  }
@@ -1538,7 +1538,7 @@ yyreduce:
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 183 "../../intl/plural.y"
+#line 183 "plural.y"
     {
 	    (yyval.exp) = new_exp_2 ((yyvsp[(2) - (3)].op), (yyvsp[(1) - (3)].exp), (yyvsp[(3) - (3)].exp));
 	  }
@@ -1547,7 +1547,7 @@ yyreduce:
   case 10:
 
 /* Line 1455 of yacc.c  */
-#line 187 "../../intl/plural.y"
+#line 187 "plural.y"
     {
 	    (yyval.exp) = new_exp_1 (lnot, (yyvsp[(2) - (2)].exp));
 	  }
@@ -1556,7 +1556,7 @@ yyreduce:
   case 11:
 
 /* Line 1455 of yacc.c  */
-#line 191 "../../intl/plural.y"
+#line 191 "plural.y"
     {
 	    (yyval.exp) = new_exp_0 (var);
 	  }
@@ -1565,7 +1565,7 @@ yyreduce:
   case 12:
 
 /* Line 1455 of yacc.c  */
-#line 195 "../../intl/plural.y"
+#line 195 "plural.y"
     {
 	    if (((yyval.exp) = new_exp_0 (num)) != NULL)
 	      (yyval.exp)->val.num = (yyvsp[(1) - (1)].num);
@@ -1575,7 +1575,7 @@ yyreduce:
   case 13:
 
 /* Line 1455 of yacc.c  */
-#line 200 "../../intl/plural.y"
+#line 200 "plural.y"
     {
 	    (yyval.exp) = (yyvsp[(2) - (3)].exp);
 	  }
@@ -1584,7 +1584,7 @@ yyreduce:
 
 
 /* Line 1455 of yacc.c  */
-#line 1588 "../../intl/plural.c"
+#line 1588 "plural.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1796,7 +1796,7 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 205 "../../intl/plural.y"
+#line 205 "plural.y"
 
 
 void
