@@ -43,12 +43,12 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include "global.h"
+#include "lib/global.h"
 #include "background.h"
 #include "wtools.h"
 #include "layout.h"	/* repaint_screen() */
 #include "fileopctx.h"	/* FileOpContext */
-#include "../src/tty/key.h"	/* add_select_channel(), delete_select_channel() */
+#include "lib/tty/key.h"	/* add_select_channel(), delete_select_channel() */
 
 enum ReturnType {
     Return_String,
@@ -390,8 +390,8 @@ background_attention (int fd, void *closure)
 	    write (to_child_fd, &len, sizeof (len));
 	    if (len){
 		write (to_child_fd, resstr, len);
-		g_free (resstr);
 	    }
+	    g_free (resstr);
 	} else {
 	    len = 0;
 	    write (to_child_fd, &len, sizeof (len));
