@@ -36,18 +36,18 @@
 #include <pwd.h>
 #include <unistd.h>
 
-#include "global.h"
+#include "lib/global.h"
 
-#include "../src/tty/tty.h"
-#include "../src/tty/key.h"		/* XCTRL and ALT macros */
+#include "lib/tty/tty.h"
+#include "lib/tty/key.h"		/* XCTRL and ALT macros */
+#include "lib/vfs/mc-vfs/vfs.h"
+#include "lib/strescape.h"
+#include "lib/strutil.h"
 
 #include "dialog.h"
 #include "widget.h"
 #include "wtools.h"
 #include "main.h"		/* show_all_if_ambiguous */
-#include "util.h"
-#include "../src/strescape.h"
-#include "strutil.h"
 
 typedef char *CompletionFunction (const char * text, int state, INPUT_COMPLETE_FLAGS flags);
 
@@ -459,7 +459,7 @@ command_completion_function (const char *_text, int state, INPUT_COMPLETE_FLAGS
     static const char *path_end;
     static gboolean isabsolute;
     static int phase;
-    static int text_len;
+    static size_t text_len;
     static const char *const *words;
     static char *path;
     static char *cur_path;
@@ -520,16 +520,20 @@ command_completion_function (const char *_text, int state, INPUT_COMPLETE_FLAGS
     switch (phase) {
     case 0:			/* Reserved words */
 	while (*words) {
-	    if (!strncmp (*words, text, text_len))
+	    if (strncmp (*words, text, text_len) == 0) {
+		g_free (text);
 		return g_strdup (*(words++));
+	    }
 	    words++;
 	}
 	phase++;
 	words = bash_builtins;
     case 1:			/* Builtin commands */
 	while (*words) {
-	    if (!strncmp (*words, text, text_len))
+	    if (strncmp (*words, text, text_len) == 0) {
+		g_free (text);
 		return g_strdup (*(words++));
+	    }
 	    words++;
 	}
 	phase++;
@@ -979,20 +983,20 @@ query_callback (Dlg_head *h, Widget *sender,
                         if (strncmp (&e1->text[end - start], buff, bl) == 0) {
 			    if (need_redraw) {
 				char *si, *sl;
-				char *ni, *nl;
+				char *nexti, *nextl;
                                 si = &(e1->text[end - start]);
                                 sl = &(last_text[end - start]);
                                 
 				for (; si[0] != '\0' && sl[0] != '\0';) {
                                     
-                                    ni = str_get_next_char (si);
-                                    nl = str_get_next_char (sl);
+                                    nexti = str_get_next_char (si);
+                                    nextl = str_get_next_char (sl);
                                     
-                                    if (ni - si != nl - sl) break;
-                                    if (strncmp (si, sl, ni - si) != 0) break;
+                                    if (nexti - si != nextl - sl) break;
+                                    if (strncmp (si, sl, nexti - si) != 0) break;
                                     
-                                    si = ni;
-                                    sl = nl;
+                                    si = nexti;
+                                    sl = nextl;
                                 }
                                 
 				if (low > si - &e1->text[end - start])
