@@ -34,13 +34,13 @@
 #endif
 #include <unistd.h>
 
-#include "global.h"
+#include "lib/global.h"
 
-#include "../src/tty/tty.h"
-#include "../src/skin/skin.h"		/* tty_set_normal_attrs */
-#include "../src/tty/win.h"
+#include "lib/tty/tty.h"
+#include "lib/skin.h"		/* tty_set_normal_attrs */
+#include "lib/tty/win.h"
 
-#include "cons.saver.h"
+#include "consaver/cons.saver.h"
 
 signed char console_flag = 0;
 
