@@ -8,7 +8,7 @@
 
 #include <sys/stat.h>
 
-#include "global.h"
+#include "lib/global.h"
 
 #define MIN_FILES 128
 #define RESIZE_STEPS 128
@@ -41,11 +41,11 @@ typedef struct {
 typedef int sortfn (const void *, const void *);
 
 int do_load_dir (const char *path, dir_list * list, sortfn * sort, int reverse,
-		 int case_sensitive, int exec_ff, const char *filter);
+		 int case_sensitive, int exec_ff, const char *fltr);
 void do_sort (dir_list * list, sortfn * sort, int top, int reverse,
 	      int case_sensitive, int exec_ff);
 int do_reload_dir (const char *path, dir_list * list, sortfn * sort, int count,
-		   int reverse, int case_sensitive, int exec_ff, const char *filter);
+		   int reverse, int case_sensitive, int exec_ff, const char *fltr);
 void clean_dir (dir_list * list, int count);
 gboolean set_zero_dir (dir_list *list);
 int handle_path (dir_list *list, const char *path, struct stat *buf1,
