@@ -56,6 +56,7 @@
 #include "src/widget.h"         /* listbox_new() */
 #include "src/layout.h"         /* clr_scr() */
 #include "src/main.h"           /* mc_home */
+#include "src/setup.h"          /* option_tab_spacing */
 #include "src/help.h"           /* interactive_display() */
 #include "src/wtools.h"         /* message() */
 #include "src/charsets.h"
@@ -1626,13 +1627,14 @@ edit_replace_cmd__conv_to_display (char *str)
 {
 #ifdef HAVE_CHARSET
     GString *tmp;
-    tmp = str_convert_to_display (str);
 
-    if (tmp && tmp->len)
+    tmp = str_convert_to_display (str);
+    if (tmp != NULL)
     {
-        return g_string_free (tmp, FALSE);
+        if (tmp->len != 0)
+            return g_string_free (tmp, FALSE);
+        g_string_free (tmp, TRUE);
     }
-    g_string_free (tmp, TRUE);
 #endif
     return g_strdup (str);
 }
@@ -1642,14 +1644,14 @@ edit_replace_cmd__conv_to_input (char *str)
 {
 #ifdef HAVE_CHARSET
     GString *tmp;
-    tmp = str_convert_to_input (str);
 
-    if (tmp && tmp->len)
+    tmp = str_convert_to_input (str);
+    if (tmp != NULL)
     {
-        return g_string_free (tmp, FALSE);
+        if (tmp->len != 0)
+            return g_string_free (tmp, FALSE);
+        g_string_free (tmp, TRUE);
     }
-    g_string_free (tmp, TRUE);
-    return g_strdup (str);
 #endif
     return g_strdup (str);
 }
@@ -1665,8 +1667,7 @@ edit_replace_cmd (WEdit * edit, int again)
     char *input2 = NULL;
     char *disp1 = NULL;
     char *disp2 = NULL;
-    int replace_yes;
-    long times_replaced = 0, last_search;
+    long times_replaced = 0;
     gboolean once_found = FALSE;
 
     if (!edit)
@@ -1676,8 +1677,6 @@ edit_replace_cmd (WEdit * edit, int again)
         return;
     }
 
-    last_search = edit->last_byte;
-
     edit->force |= REDRAW_COMPLETELY;
 
     if (again && !saved1 && !saved2)
@@ -1730,7 +1729,7 @@ edit_replace_cmd (WEdit * edit, int again)
         if (edit->search == NULL)
         {
             edit->search_start = edit->curs1;
-            return;
+            goto cleanup;
         }
         edit->search->search_type = edit_search_options.type;
         edit->search->is_all_charsets = edit_search_options.all_codepages;
@@ -1750,7 +1749,6 @@ edit_replace_cmd (WEdit * edit, int again)
     do
     {
         gsize len = 0;
-        long new_start;
 
         if (!editcmd_find (edit, &len))
         {
@@ -1762,14 +1760,14 @@ edit_replace_cmd (WEdit * edit, int again)
             break;
         }
         once_found = TRUE;
-        new_start = edit->search->normal_offset;
 
-        edit->search_start = new_start = edit->search->normal_offset;
+        edit->search_start = edit->search->normal_offset;
         /*returns negative on not found or error in pattern */
 
-        if (edit->search_start >= 0)
+        if ((edit->search_start >= 0) && (edit->search_start < edit->last_byte))
         {
-            guint i;
+            gsize i;
+            GString *tmp_str, *repl_str;
 
             edit->found_start = edit->search_start;
             i = edit->found_len = len;
@@ -1777,11 +1775,11 @@ edit_replace_cmd (WEdit * edit, int again)
             edit_cursor_move (edit, edit->search_start - edit->curs1);
             edit_scroll_screen_over_cursor (edit);
 
-            replace_yes = 1;
-
             if (edit->replace_mode == 0)
             {
                 int l;
+                int prompt;
+
                 l = edit->curs_row - edit->num_widget_lines / 3;
                 if (l > 0)
                     edit_scroll_downward (edit, l);
@@ -1797,82 +1795,86 @@ edit_replace_cmd (WEdit * edit, int again)
                 /* and prompt 2/3 down */
                 disp1 = edit_replace_cmd__conv_to_display (saved1);
                 disp2 = edit_replace_cmd__conv_to_display (saved2);
-                switch (editcmd_dialog_replace_prompt_show (edit, disp1, disp2, -1, -1))
-                {
-                case B_ENTER:
-                    replace_yes = 1;
-                    break;
-                case B_SKIP_REPLACE:
-                    replace_yes = 0;
-                    break;
-                case B_REPLACE_ALL:
-                    edit->replace_mode = 1;
-                    break;
-                case B_CANCEL:
-                    replace_yes = 0;
-                    edit->replace_mode = -1;
-                    break;
-                }
+                prompt = editcmd_dialog_replace_prompt_show (edit, disp1, disp2, -1, -1);
                 g_free (disp1);
                 g_free (disp2);
-            }
-            if (replace_yes)
-            {                   /* delete then insert new */
-                GString *repl_str, *tmp_str;
-                tmp_str = g_string_new (input2);
 
-                repl_str = mc_search_prepare_replace_str (edit->search, tmp_str);
-                g_string_free (tmp_str, TRUE);
-                if (edit->search->error != MC_SEARCH_E_OK)
+                if (prompt == B_REPLACE_ALL)
+                    edit->replace_mode = 1;
+                else if (prompt == B_SKIP_REPLACE)
                 {
-                    edit_error_dialog (_("Replace"), edit->search->error_str);
-                    break;
+                    if (edit_search_options.backwards)
+                        edit->search_start--;
+                    else
+                        edit->search_start++;
+                    continue; /* loop */
+                }
+                else if (prompt == B_CANCEL)
+                {
+                    edit->replace_mode = -1;
+                    break; /* loop */
                 }
-
-                while (i--)
-                    edit_delete (edit, 1);
-
-                while (++i < repl_str->len)
-                    edit_insert (edit, repl_str->str[i]);
-
-                g_string_free (repl_str, TRUE);
-                edit->found_len = i;
             }
+
+            /* don't process string each time */
+            tmp_str = g_string_new (input2);
+            repl_str = mc_search_prepare_replace_str (edit->search, tmp_str);
+            g_string_free (tmp_str, TRUE);
+
+            if (edit->search->error != MC_SEARCH_E_OK)
+            {
+                edit_error_dialog (_("Replace"), edit->search->error_str);
+                g_string_free (repl_str, TRUE);
+                break;
+            }
+
+              /* delete then insert new */
+            for (i = 0; i < len; i++)
+                edit_delete (edit, 1);
+
+            for (i = 0; i < repl_str->len; i++)
+                edit_insert (edit, repl_str->str[i]);
+
+            edit->found_len = repl_str->len;
+            g_string_free (repl_str, TRUE);
+            times_replaced++;
+
             /* so that we don't find the same string again */
             if (edit_search_options.backwards)
-            {
-                last_search = edit->search_start;
                 edit->search_start--;
-            }
             else
             {
-                edit->search_start += i;
-                last_search = edit->last_byte;
+                edit->search_start += edit->found_len;
+
+                if (edit->search_start >= edit->last_byte)
+                    break;
             }
+
             edit_scroll_screen_over_cursor (edit);
         }
         else
         {
-            const char *msg = _(" Replace ");
             /* try and find from right here for next search */
             edit->search_start = edit->curs1;
             edit_update_curs_col (edit);
 
             edit->force |= REDRAW_PAGE;
             edit_render_keypress (edit);
-            if (times_replaced)
-            {
-                message (D_NORMAL, msg, _(" %ld replacements made. "), times_replaced);
-            }
-            else
-                query_dialog (msg, _(" Search string not found "), D_NORMAL, 1, _("&OK"));
-            edit->replace_mode = -1;
+
+            if (times_replaced == 0)
+                query_dialog (_("Replace"), _(" Search string not found "), D_NORMAL, 1, _("&OK"));
+            break;
         }
     }
     while (edit->replace_mode >= 0);
 
-    edit->force = REDRAW_COMPLETELY;
     edit_scroll_screen_over_cursor (edit);
+    edit->force |= REDRAW_COMPLETELY;
+    edit_render_keypress (edit);
+
+    if ((edit->replace_mode == 1) && (times_replaced != 0))
+        message (D_NORMAL, _("Replace"), _("%ld replacements made"), times_replaced);
+
   cleanup:
     g_free (input1);
     g_free (input2);
