@@ -1,9 +1,15 @@
+
+/** \file fileopctx.h
+ *  \brief Header: file operation contexts
+ *  \date 1998
+ *  \author Federico Mena <federico@nuclecu.unam.mx>
+ *  \author Miguel de Icaza <miguel@nuclecu.unam.mx>
+ */
+
 /* File operation contexts for the Midnight Commander
  *
- * Copyright (C) 1998 The Free Software Foundation
+ * Copyright (C) 1998 Free Software Foundation, Inc.
  *
- * Authors: Federico Mena <federico@nuclecu.unam.mx>
- *          Miguel de Icaza <miguel@nuclecu.unam.mx>
  */
 
 #ifndef FILEOPCTX_H
@@ -11,15 +17,23 @@
 
 #include <sys/stat.h>
 #include <sys/types.h>
-#include "eregex.h"
 
+struct mc_search_struct;
+typedef enum {
+	OP_COPY,
+	OP_MOVE,
+	OP_DELETE
+} FileOperation;
 
-typedef int (*mc_stat_fn) (char *filename, struct stat *buf);
+typedef int (*mc_stat_fn) (const char *filename, struct stat *buf);
 
 /* This structure describes a context for file operations.  It is used to update
  * the progress windows and pass around options.
  */
-typedef struct {
+typedef struct FileOpContext {
+	/* Operation type (copy, move, delete) */
+	FileOperation operation;
+
 	/* The estimated time of arrival in seconds */
 	double eta_secs;
 
@@ -47,7 +61,7 @@ typedef struct {
 	int recursive_result;
 
 	/* Whether to do a reget */
-	int do_reget;
+	off_t do_reget;
 
 	/* Controls appending to files */
 	int do_append;
@@ -77,19 +91,16 @@ typedef struct {
 	/* The mask of files to actually operate on */
 	char *dest_mask;
 
-	/* Regex for the file mask */
-	struct re_pattern_buffer rx;
-	struct re_registers regs;
-
+        struct mc_search_struct *search_handle;
 	/* Whether to dive into subdirectories for recursive operations */
 	int dive_into_subdirs;
 
 	/* When moving directories cross filesystem boundaries delete the
-	 * successfull copied files when all files below the directory and its
+	 * successfully copied files when all files below the directory and its
 	 * subdirectories were processed.
 	 *
 	 * If erase_at_end is zero files will be deleted immediately after their
-	 * successful copy (Note: this behaviour is not tested and at the moment
+	 * successful copy (Note: this behavior is not tested and at the moment
 	 * it can't be changed at runtime).
 	 */
 	int erase_at_end;
@@ -103,23 +114,17 @@ typedef struct {
 } FileOpContext;
 
 
-FileOpContext *file_op_context_new (void);
+FileOpContext *file_op_context_new (FileOperation op);
 void file_op_context_destroy (FileOpContext *ctx);
 
 
-typedef enum {
-	OP_COPY,
-	OP_MOVE,
-	OP_DELETE
-} FileOperation;
-
-extern char *op_names [3];
+extern const char *op_names [3];
 
 typedef enum {
-	FILE_CONT,
-	FILE_RETRY,
-	FILE_SKIP,
-	FILE_ABORT
+	FILE_CONT  = 0,
+	FILE_RETRY = 1,
+	FILE_SKIP  = 2,
+	FILE_ABORT = 3
 } FileProgressStatus;
 
 typedef enum {
@@ -138,21 +143,22 @@ enum OperationMode {
 
 /* The following functions are implemented separately by each port */
 
-void file_op_context_create_ui (FileOpContext *ctx, FileOperation op, int with_eta);
+void file_op_context_create_ui (FileOpContext *ctx, int with_eta);
+void file_op_context_create_ui_without_init (FileOpContext *ctx, int with_eta);
 void file_op_context_destroy_ui (FileOpContext *ctx);
 
 FileProgressStatus file_progress_show (FileOpContext *ctx, off_t done, off_t total);
 FileProgressStatus file_progress_show_count (FileOpContext *ctx, off_t done, off_t total);
 FileProgressStatus file_progress_show_bytes (FileOpContext *ctx, double done, double total);
-FileProgressStatus file_progress_show_source (FileOpContext *ctx, char *path);
-FileProgressStatus file_progress_show_target (FileOpContext *ctx, char *path);
-FileProgressStatus file_progress_show_deleting (FileOpContext *ctx, char *path);
+FileProgressStatus file_progress_show_source (FileOpContext *ctx, const char *path);
+FileProgressStatus file_progress_show_target (FileOpContext *ctx, const char *path);
+FileProgressStatus file_progress_show_deleting (FileOpContext *ctx, const char *path);
 
-void file_progress_set_stalled_label (FileOpContext *ctx, char *stalled_msg);
+void file_progress_set_stalled_label (FileOpContext *ctx, const char *stalled_msg);
 
 FileProgressStatus file_progress_real_query_replace (FileOpContext *ctx,
 						     enum OperationMode mode,
-						     char *destname,
+						     const char *destname,
 						     struct stat *_s_stat,
 						     struct stat *_d_stat);
 
