@@ -1,3 +1,8 @@
+
+/** \file history.h
+ *  \brief Header: defines history section names
+ */
+
 #ifndef __MC_HISTORY_H
 #define __MC_HISTORY_H
 
@@ -33,4 +38,6 @@
 
 #define MC_HISTORY_HOTLIST_ADD		"mc.hotlist.add"
 
+#define MC_HISTORY_SHARED_SEARCH	"mc.shared.search"
+
 #endif
