@@ -34,15 +34,14 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include "global.h"
+#include "lib/global.h"
+#include "lib/tty/win.h"
+#include "lib/tty/key.h"		/* KEY_M_ */
+#include "lib/tty/tty.h"		/* keys */
+#include "lib/strutil.h"
 
 #include "cmddef.h"		/* CK_ cmd name const */
-#include "tty/win.h"
-#include "tty/key.h"		/* KEY_M_ */
-#include "tty/tty.h"		/* keys */
 #include "wtools.h"
-#include "strutil.h"
-
 #include "keybind.h"
 
 static name_keymap_t command_names[] = {
@@ -84,6 +83,7 @@ static name_keymap_t command_names[] = {
     { "EditCopy",                          CK_Copy },
     { "EditMove",                          CK_Move },
     { "EditRemove",                        CK_Remove },
+    { "EditMarkAll",                       CK_Mark_All },
     { "EditUnmark",                        CK_Unmark },
     { "EditSaveBlock",                     CK_Save_Block },
     { "EditColumnMark",                    CK_Column_Mark },
@@ -92,6 +92,7 @@ static name_keymap_t command_names[] = {
     { "EditReplace",                       CK_Replace },
     { "EditReplaceAgain",                  CK_Replace_Again },
     { "EditCompleteWord",                  CK_Complete_Word },
+
 #if 0
     { "EditDebugStart",                    CK_Debug_Start },
     { "EditDebugStop",                     CK_Debug_Stop },
@@ -342,9 +343,9 @@ static name_keymap_t command_names[] = {
     { "CmdReverseSelection",             CK_ReverseSelectionCmd },
     { "CmdSaveSetup",                    CK_SaveSetupCmd },
     { "CmdSelect",                       CK_SelectCmd },
-#if defined (USE_NETCODE) && defined (WITH_SMBFS)
+#if defined (USE_NETCODE) && defined (ENABLE_VFS_SMB)
     { "CmdSmblinkCmd",                   CK_SmblinkCmd },
-#endif
+#endif /* USE_NETCODE || ENABLE_VFS_SMB */
     { "CmdSwapPanel",                    CK_SwapCmd },
     { "CmdSymlink",                      CK_SymlinkCmd },
     { "CmdTree",                         CK_TreeCmd },
@@ -951,9 +952,9 @@ keybind_cmd_bind (GArray *keymap, const char *keybind, unsigned long action)
 }
 
 unsigned long
-lookup_action (const char *keyname)
+lookup_action (const char *name)
 {
-    const name_keymap_t key = { keyname, 0 };
+    const name_keymap_t key = { name, 0 };
     name_keymap_t *res;
 
     sort_command_names ();
