@@ -969,9 +969,10 @@ set_display_type (int num, panel_view_mode_t type)
      *   current_panel causes segfault, e.g. C-Enter, C-x c, ...
      */
 
-    if ((type != view_listing)
-	&& (current_panel == (WPanel *) old_widget))
-	    current_panel = num == 0 ? right_panel : left_panel;
+    if ((type != view_listing) && (current_panel == (WPanel *) old_widget))
+        current_panel = num == 0 ? right_panel : left_panel;
+
+    g_free (old_widget);
 }
 
 /* This routine is deeply sticked to the two panels idea.
