@@ -1,7 +1,9 @@
 /* Man page to help file converter
-   Copyright (C) 1994, 1995 Janne Kukonlehto
+   Copyright (C) 1994, 1995, 1998, 2000, 2001, 2002, 2003, 2004, 2005,
+   2007 Free Software Foundation, Inc.
 		 2002  Andrew V. Samoilov
 		 2002  Pavel Roskin
+		 2010 Andrew Borodin
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,15 +19,20 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
+/** \file man2hlp.c
+ *  \brief Source: man page to help file converter
+ */
+
 #include <config.h>
+
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 #include <string.h>
 
 #include <glib.h>
+
 #include "help.h"
-#include "glibcompat.h"
 
 #define BUFFER_SIZE 256
 
@@ -181,7 +188,7 @@ static int
 string_len (const char *buffer)
 {
     static int anchor_flag = 0;	/* Flag: Inside hypertext anchor name */
-    static int link_flag = 0;	/* Flag: Inside hypertext link target name */
+    static int lc_link_flag = 0;	/* Flag: Inside hypertext link target name */
     int backslash_flag = 0;	/* Flag: Backslash quoting */
     int c;			/* Current character */
     int len = 0;		/* Result: the length of the string */
@@ -189,9 +196,9 @@ string_len (const char *buffer)
     while (*(buffer)) {
 	c = *buffer++;
 	if (c == CHAR_LINK_POINTER)
-	    link_flag = 1;	/* Link target name starts */
+	    lc_link_flag = 1;	/* Link target name starts */
 	else if (c == CHAR_LINK_END)
-	    link_flag = 0;	/* Link target name ends */
+	    lc_link_flag = 0;	/* Link target name ends */
 	else if (c == CHAR_NODE_END) {
 	    /* Node anchor name starts */
 	    anchor_flag = 1;
@@ -208,7 +215,7 @@ string_len (const char *buffer)
 	}
 	backslash_flag = 0;
 	/* Increase length if not inside anchor name or link target name */
-	if (!anchor_flag && !link_flag)
+	if (!anchor_flag && !lc_link_flag)
 	    len++;
 	if (anchor_flag && c == ']') {
 	    /* Node anchor name ends */
@@ -249,9 +256,6 @@ print_string (char *buffer)
 	    /* Skip empty strings */
 	    if (*(buffer)) {
 		len = string_len (buffer);
-		/* Change the line if about to break the right margin */
-		if (col + len >= HELP_TEXT_WIDTH)
-		    newline ();
 		/* Words are separated by spaces */
 		if (col > 0) {
 		    fputc (' ', f_out);
@@ -340,7 +344,6 @@ handle_node (char *buffer, int is_sh)
 		/* Start a new section, but omit empty section names */
 		if (*buffer) {
 		    fprintf (f_out, "%c[%s]", CHAR_NODE_END, buffer);
-		    col++;
 		    newline ();
 		}
 
@@ -665,7 +668,7 @@ main (int argc, char **argv)
     FILE *f_man;		/* Manual file */
     FILE *f_tmpl;		/* Template file */
     char buffer[BUFFER_SIZE];	/* Full input line */
-    char *node = NULL;
+    char *lc_node = NULL;
     char *outfile_buffer;	/* Large buffer to keep the output file */
     long cont_start;		/* Start of [Contents] */
     long file_end;		/* Length of the output file */
@@ -748,21 +751,21 @@ main (int argc, char **argv)
     /* Repeat for each input line */
     /* Read a line */
     while (fgets (buffer, BUFFER_SIZE, f_tmpl)) {
-	if (node) {
+	if (lc_node) {
 	    if (*buffer && *buffer != '\n') {
 		cnode->lname = strdup (buffer);
-		node = strchr (cnode->lname, '\n');
-		if (node)
-		    *node = 0;
+		lc_node = strchr (cnode->lname, '\n');
+		if (lc_node)
+		    *lc_node = 0;
 	    }
-	    node = NULL;
+	    lc_node = NULL;
 	} else {
-	    node = strchr (buffer, CHAR_NODE_END);
-	    if (node && (node[1] == '[')) {
-		char *p = strchr (node, ']');
+	    lc_node = strchr (buffer, CHAR_NODE_END);
+	    if (lc_node && (lc_node[1] == '[')) {
+		char *p = strchr (lc_node, ']');
 		if (p) {
-		    if (strncmp (node + 1, "[main]", 6) == 0) {
-			node = 0;
+		    if (strncmp (lc_node + 1, "[main]", 6) == 0) {
+			lc_node = NULL;
 		    } else {
 			if (!cnode) {
 			    cnode = &nodes;
@@ -770,16 +773,16 @@ main (int argc, char **argv)
 			    cnode->next = malloc (sizeof (nodes));
 			    cnode = cnode->next;
 			}
-			cnode->node = strdup (node + 2);
-			cnode->node[p - node - 2] = 0;
+			cnode->node = strdup (lc_node + 2);
+			cnode->node[p - lc_node - 2] = 0;
 			cnode->lname = NULL;
 			cnode->next = NULL;
 			cnode->heading_level = 0;
 		    }
 		} else
-		    node = NULL;
+		    lc_node = NULL;
 	    } else
-		node = NULL;
+		lc_node = NULL;
 	}
 	fputs (buffer, f_out);
     }
@@ -823,12 +826,12 @@ main (int argc, char **argv)
     }
 
     for (cnode = &nodes; cnode && cnode->node;) {
-	char *node = cnode->node;
 	struct node *next = cnode->next;
+	lc_node = cnode->node;
 
-	if (*node)
+	if (*lc_node)
 	    fprintf (f_out, "  %*s\001%s\002%s\003", cnode->heading_level,
-		     "", cnode->lname ? cnode->lname : node, node);
+		     "", cnode->lname ? cnode->lname : lc_node, lc_node);
 	fprintf (f_out, "\n");
 
 	free (cnode->node);
