@@ -26,19 +26,19 @@
 #include <string.h>
 #include <sys/types.h>
 
-#include "global.h"
+#include "lib/global.h"
 
-#include "../src/tty/tty.h"
-#include "../src/skin/skin.h"
-#include "../src/tty/mouse.h"
-#include "../src/tty/key.h"	/* key macros */
+#include "lib/tty/tty.h"
+#include "lib/skin.h"
+#include "lib/tty/mouse.h"
+#include "lib/tty/key.h"	/* key macros */
+#include "lib/strutil.h"
 
 #include "cmddef.h"		/* CK_Ignore_Key */
 #include "help.h"
 #include "dialog.h"
 #include "widget.h"
 #include "main.h"		/* is_right */
-#include "strutil.h"
 #include "menu.h"
 
 int menubar_visible = 1;	/* This is the new default */
@@ -209,7 +209,7 @@ static void
 menubar_set_color (WMenuBar *menubar, gboolean current, gboolean hotkey)
 {
     if (!menubar->is_active)
-	tty_setcolor (hotkey ? COLOR_HOT_FOCUS : SELECTED_COLOR);
+	tty_setcolor (MENU_INACTIVE_COLOR);
     else if (current)
 	tty_setcolor (hotkey ? MENU_HOTSEL_COLOR : MENU_SELECTED_COLOR);
     else
@@ -222,7 +222,7 @@ menubar_draw (WMenuBar *menubar)
     GList *i;
 
     /* First draw the complete menubar */
-    tty_setcolor (menubar->is_active ? MENU_ENTRY_COLOR : SELECTED_COLOR);
+    tty_setcolor (menubar->is_active ? MENU_ENTRY_COLOR : MENU_INACTIVE_COLOR);
     tty_draw_hline (menubar->widget.y, menubar->widget.x, ' ', menubar->widget.cols);
 
     /* Now each one of the entries */
