@@ -15,14 +15,17 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
-#ifdef HAVE_CONFIG_H
+/** \file mountlist.c
+ *  \brief Source: list of mounted filesystems
+ */
+
 #include <config.h>
-#endif
 
-#include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <sys/types.h>
+
 /* This header needs to be included before sys/mount.h on *BSD */
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
@@ -49,6 +52,10 @@
 #include <sys/mount.h>
 #endif
 
+#ifdef MOUNTED_GETMNTINFO2	/* NetBSD 3.0.  */
+#include <sys/statvfs.h>
+#endif
+
 #ifdef MOUNTED_GETMNT		/* Ultrix.  */
 #include <sys/mount.h>
 #include <sys/fs_types.h>
@@ -102,9 +109,8 @@
 #include <sys/statvfs.h>
 #endif
 
-#include "global.h"
+#include "lib/global.h"
 #include "mountlist.h"
-#include "util.h"
 
 #ifdef DOLPHIN
 /* So special that it's not worth putting this in autoconf.  */
@@ -132,11 +138,11 @@ struct mount_entry
 
 struct fs_usage
 {
-  long fsu_blocks;		/* Total blocks. */
-  long fsu_bfree;		/* Free blocks available to superuser. */
-  long fsu_bavail;		/* Free blocks available to non-superuser. */
-  long fsu_files;		/* Total file nodes. */
-  long fsu_ffree;		/* Free file nodes. */
+    fsblkcnt_t fsu_blocks;	/* Total blocks. */
+    fsblkcnt_t fsu_bfree;	/* Free blocks available to superuser. */
+    fsblkcnt_t fsu_bavail;	/* Free blocks available to non-superuser. */
+    fsfilcnt_t fsu_files;	/* Total file nodes. */
+    fsfilcnt_t fsu_ffree;	/* Free file nodes. */
 };
 
 static int get_fs_usage (char *path, struct fs_usage *fsp);
@@ -145,6 +151,19 @@ static int get_fs_usage (char *path, struct fs_usage *fsp);
 
 static struct mount_entry *mount_list = NULL;
 
+static void free_mount_entry (struct mount_entry *me)
+{
+    if (!me)
+	return;
+    if (me->me_devname)
+	free (me->me_devname);
+    if (me->me_mountdir)
+	free (me->me_mountdir);
+    if (me->me_type)
+	free (me->me_type);
+    free (me);
+}
+
 #ifdef MOUNTED_GETMNTENT1	/* 4.3BSD, SunOS, HP-UX, Dynix, Irix.  */
 /* Return the value of the hexadecimal number represented by CP.
    No prefix (like '0x') or suffix (like 'h') is expected to be
@@ -170,14 +189,12 @@ static int xatoi (const char *cp)
 }
 #endif /* MOUNTED_GETMNTENT1 */
 
-#if defined (MOUNTED_GETMNTINFO) && !defined (HAVE_F_FSTYPENAME)
+#ifdef MOUNTED_GETMNTINFO
+
+#ifndef HAVE_STRUCT_STATFS_F_FSTYPENAME
 static char *fstype_to_string (short t)
 {
     switch (t) {
-    case MOUNT_UFS:
-	return "ufs";
-    case MOUNT_NFS:
-	return "nfs";
 #ifdef MOUNT_PC
     case MOUNT_PC:
 	return "pc";
@@ -197,12 +214,78 @@ static char *fstype_to_string (short t)
 #ifdef MOUNT_TMP
     case MOUNT_TMP:
 	return "tmp";
+#endif
+#ifdef MOUNT_UFS
+   case MOUNT_UFS:
+     return "ufs" ;
+#endif
+#ifdef MOUNT_NFS
+   case MOUNT_NFS:
+     return "nfs" ;
+#endif
+#ifdef MOUNT_MSDOS
+   case MOUNT_MSDOS:
+     return "msdos" ;
+#endif
+#ifdef MOUNT_LFS
+   case MOUNT_LFS:
+     return "lfs" ;
+#endif
+#ifdef MOUNT_LOFS
+   case MOUNT_LOFS:
+     return "lofs" ;
+#endif
+#ifdef MOUNT_FDESC
+   case MOUNT_FDESC:
+     return "fdesc" ;
+#endif
+#ifdef MOUNT_PORTAL
+   case MOUNT_PORTAL:
+     return "portal" ;
+#endif
+#ifdef MOUNT_NULL
+   case MOUNT_NULL:
+     return "null" ;
+#endif
+#ifdef MOUNT_UMAP
+   case MOUNT_UMAP:
+     return "umap" ;
+#endif
+#ifdef MOUNT_KERNFS
+   case MOUNT_KERNFS:
+     return "kernfs" ;
+#endif
+#ifdef MOUNT_PROCFS
+   case MOUNT_PROCFS:
+     return "procfs" ;
+#endif
+#ifdef MOUNT_AFS
+   case MOUNT_AFS:
+     return "afs" ;
+#endif
+#ifdef MOUNT_CD9660
+   case MOUNT_CD9660:
+     return "cd9660" ;
+#endif
+#ifdef MOUNT_UNION
+   case MOUNT_UNION:
+     return "union" ;
+#endif
+#ifdef MOUNT_DEVFS
+   case MOUNT_DEVFS:
+     return "devfs" ;
+#endif
+#ifdef MOUNT_EXT2FS
+   case MOUNT_EXT2FS:
+     return "ext2fs" ;
 #endif
     default:
 	return "?";
     }
 }
-#endif /* MOUNTED_GETMNTINFO && !HAVE_F_FSTYPENAME */
+#endif /* ! HAVE_STRUCT_STATFS_F_FSTYPENAME */
+
+#endif /* MOUNTED_GETMNTINFO */
 
 #ifdef MOUNTED_VMOUNT		/* AIX.  */
 static char *
@@ -232,6 +315,9 @@ read_filesystem_list (int need_fs_type, int all_fs)
     struct mount_entry *me;
     struct mount_entry *mtail;
 
+    (void) need_fs_type;
+    (void) all_fs;
+
     /* Start the list off with a dummy entry. */
     me = (struct mount_entry *) malloc (sizeof (struct mount_entry));
     me->me_next = NULL;
@@ -290,7 +376,7 @@ read_filesystem_list (int need_fs_type, int all_fs)
 	    me = (struct mount_entry *) malloc (sizeof (struct mount_entry));
 	    me->me_devname = strdup (fsp->f_mntfromname);
 	    me->me_mountdir = strdup (fsp->f_mntonname);
-#ifdef HAVE_F_FSTYPENAME
+#ifdef HAVE_STRUCT_STATFS_F_FSTYPENAME
 	    me->me_type = strdup (fsp->f_fstypename);
 #else
 	    me->me_type = fstype_to_string (fsp->f_type);
@@ -306,6 +392,28 @@ read_filesystem_list (int need_fs_type, int all_fs)
     }
 #endif /* MOUNTED_GETMNTINFO */
 
+#ifdef MOUNTED_GETMNTINFO2	/* NetBSD 3.0.  */
+    {
+	struct statvfs *fsp;
+	int entries;
+
+	entries = getmntinfo (&fsp, MNT_NOWAIT);
+	if (entries < 0)
+	    return NULL;
+	for (; entries-- > 0; fsp++) {
+	    me = (struct mount_entry *) malloc (sizeof (struct mount_entry));
+	    me->me_devname = strdup (fsp->f_mntfromname);
+	    me->me_mountdir = strdup (fsp->f_mntonname);
+	    me->me_type = strdup (fsp->f_fstypename);
+	    me->me_dev = (dev_t) -1;	/* Magic; means not known yet. */
+
+	    /* Add to the linked list. */
+	    mtail->me_next = me;
+	    mtail = me;
+	}
+    }
+#endif /* MOUNTED_GETMNTINFO2 */
+
 #ifdef MOUNTED_GETMNT		/* Ultrix.  */
     {
 	int offset = 0;
@@ -579,10 +687,25 @@ read_filesystem_list(int need_fs_type, int all_fs)
 }
 #endif /* HAVE_INFOMOUNT_QNX */
 
+void
+free_my_statfs (void)
+{
+#ifdef HAVE_INFOMOUNT_LIST
+    while (mount_list) {
+	struct mount_entry *next = mount_list->me_next;
+	free_mount_entry (mount_list);
+	mount_list = next;
+    }
+    mount_list = NULL;
+#endif /* HAVE_INFOMOUNT_LIST */
+}
+
+
 void
 init_my_statfs (void)
 {
 #ifdef HAVE_INFOMOUNT_LIST
+    free_my_statfs ();
     mount_list = read_filesystem_list (1, 1);
 #endif /* HAVE_INFOMOUNT_LIST */
 }
@@ -607,6 +730,7 @@ my_statfs (struct my_statfs *myfs_stats, const char *path)
     }
 
     if (entry){
+	memset (&fs_use, 0, sizeof (struct fs_usage));
 	get_fs_usage (entry->me_mountdir, &fs_use);
 
 	myfs_stats->type = entry->me_dev;
@@ -663,8 +787,8 @@ my_statfs (struct my_statfs *myfs_stats, const char *path)
    BLOCKS FROMSIZE-byte blocks, rounding away from zero.
    TOSIZE must be positive.  Return -1 if FROMSIZE is not positive.  */
 
-static long
-fs_adjust_blocks (long blocks, int fromsize, int tosize)
+static fsblkcnt_t
+fs_adjust_blocks (fsblkcnt_t blocks, int fromsize, int tosize)
 {
     if (tosize <= 0)
 	abort ();
@@ -676,7 +800,7 @@ fs_adjust_blocks (long blocks, int fromsize, int tosize)
     else if (fromsize > tosize)	/* E.g., from 2048 to 512.  */
 	return blocks * (fromsize / tosize);
     else			/* E.g., from 256 to 512.  */
-	return (blocks + (blocks < 0 ? -1 : 1)) / (tosize / fromsize);
+	return blocks / (tosize / fromsize);
 }
 
 #if defined(_AIX) && defined(_I386)
