@@ -30,16 +30,15 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include "global.h"
-
-#include "../src/tty/tty.h"
+#include "lib/global.h"
+#include "lib/tty/tty.h"
+#include "lib/mcconfig.h"	/* For mc_config_save_file */
+#include "lib/strutil.h"
 
 #include "dialog.h"
 #include "widget.h"
 #include "setup.h"		/* For save_setup() */
 #include "main.h"
-#include "../src/mcconfig/mcconfig.h"	/* For mc_config_save_file */
-#include "strutil.h"
 #include "panel.h"		/* Needed for the externs */
 #include "file.h"		/* safe_delete */
 #include "layout.h"		/* For nice_rotating_dash */
