@@ -73,8 +73,6 @@
 
 
 
-extern char *find_ignore_dirs;
-
 extern int num_history_items_recorded;
 
 char *profile_name;             /* .mc/ini */
@@ -87,10 +85,14 @@ char *color_terminal_string;
 panel_view_mode_t startup_left_mode;
 panel_view_mode_t startup_right_mode;
 
+int setup_copymove_persistent_attr = 1;
+
+/* Tab size */
+int option_tab_spacing = DEFAULT_TAB_SPACING;
+
 /* Ugly hack to allow panel_save_setup to work as a place holder for */
 /* default panel values */
 int saving_setup;
-int setup_copymove_persistent_attr = 1;
 
 static char *panels_profile_name = NULL;        /* .mc/panels.ini */
 
@@ -203,9 +205,10 @@ static const struct {
     { "fish_directory_timeout", &fish_directory_timeout },
 #endif /* USE_NETCODE */
 #endif /* ENABLE_VFS */
+    /* option_tab_spacing is used in internal viewer */
+    { "editor_tab_spacing", &option_tab_spacing },
 #ifdef USE_INTERNAL_EDIT
     { "editor_word_wrap_line_length", &option_word_wrap_line_length },
-    { "editor_tab_spacing", &option_tab_spacing },
     { "editor_fill_tabs_with_spaces", &option_fill_tabs_with_spaces },
     { "editor_return_does_auto_indent", &option_return_does_auto_indent },
     { "editor_backspace_through_tabs", &option_backspace_through_tabs },
@@ -781,6 +784,14 @@ load_setup (void)
             mc_config_get_int (mc_main_config, CONFIG_APP_SECTION, int_options[i].opt_name,
                                *int_options[i].opt_addr);
 
+    if (option_tab_spacing <= 0)
+        option_tab_spacing = DEFAULT_TAB_SPACING;
+
+#ifdef USE_INTERNAL_EDIT
+    if (option_word_wrap_line_length <= 0)
+        option_word_wrap_line_length = DEFAULT_WRAP_LINE_LENGTH;
+#endif /* USE_INTERNAL_EDIT */
+
     /* Load string options */
     for (i = 0; str_options[i].opt_name != NULL; i++)
         *str_options[i].opt_addr =
@@ -812,10 +823,6 @@ load_setup (void)
 #ifdef USE_NETCODE
     ftpfs_proxy_host = mc_config_get_string (mc_main_config, "Misc", "ftp_proxy_host", "gate");
 #endif
-    setup_color_string = mc_config_get_string (mc_main_config, "Misc", "find_ignore_dirs", "");
-    if (setup_color_string[0])
-        find_ignore_dirs = g_strconcat (":", setup_color_string, ":", (char *) NULL);
-    g_free (setup_color_string);
 
     /* The default color and the terminal dependent color */
     setup_color_string = mc_config_get_string (mc_main_config, "Colors", "base_color", "");
