@@ -6,12 +6,14 @@
 #ifndef MC_USER_H
 #define MC_USER_H
 
-#include "../edit/edit.h"
+#include "lib/global.h"
 
-void user_menu_cmd (WEdit *edit_widget);
-char *expand_format (WEdit *edit_widget, char c, int quote);
+struct WEdit;
+
+void user_menu_cmd (struct WEdit *edit_widget);
+char *expand_format (struct WEdit *edit_widget, char c, gboolean do_quote);
 int check_format_view (const char *);
 int check_format_var (const char *, char **);
 int check_format_cd (const char *);
 
-#endif
+#endif					/* MC_USER_H */
