@@ -6,16 +6,16 @@
    2004, 2005, 2006, 2007, 2009 Free Software Foundation, Inc.
 
    Written by: 1994, 1995, 1998 Miguel de Icaza
-	       1994, 1995 Janne Kukonlehto
-	       1995 Jakub Jelinek
-	       1996 Joseph M. Hinkle
-	       1997 Norbert Warmuth
-	       1998 Pavel Machek
-	       2004 Roland Illig <roland.illig@gmx.de>
-	       2005 Roland Illig <roland.illig@gmx.de>
-	       2009 Slava Zanko <slavazanko@google.com>
-	       2009 Andrew Borodin <aborodin@vmail.ru>
-	       2009 Ilia Maslakov <il.smind@gmail.com>
+   1994, 1995 Janne Kukonlehto
+   1995 Jakub Jelinek
+   1996 Joseph M. Hinkle
+   1997 Norbert Warmuth
+   1998 Pavel Machek
+   2004 Roland Illig <roland.illig@gmx.de>
+   2005 Roland Illig <roland.illig@gmx.de>
+   2009 Slava Zanko <slavazanko@google.com>
+   2009 Andrew Borodin <aborodin@vmail.ru>
+   2009 Ilia Maslakov <il.smind@gmail.com>
 
    This file is part of the Midnight Commander.
 
@@ -39,12 +39,15 @@
 
 #include <limits.h>
 
-#include "../src/global.h"
-#include "../src/wtools.h"
-#include "../src/strutil.h"
-#include "../src/main.h"
-#include "../src/charsets.h"
-#include "../src/selcodepage.h"
+#include "lib/global.h"
+#include "lib/vfs/mc-vfs/vfs.h"
+#include "lib/strutil.h"
+
+#include "src/wtools.h"
+#include "src/main.h"
+#include "src/charsets.h"
+#include "src/selcodepage.h"
+
 #include "internal.h"
 #include "mcviewer.h"
 
@@ -90,9 +93,12 @@ void
 mcview_toggle_wrap_mode (mcview_t * view)
 {
     view->text_wrap_mode = !view->text_wrap_mode;
-    if (view->text_wrap_mode) {
+    if (view->text_wrap_mode)
+    {
         mcview_scroll_to_cursor (view);
-    } else {
+    }
+    else
+    {
         off_t line;
 
         mcview_offset_to_coord (view, &line, &(view->dpy_text_column), view->dpy_start);
@@ -120,11 +126,14 @@ mcview_toggle_hex_mode (mcview_t * view)
 {
     view->hex_mode = !view->hex_mode;
 
-    if (view->hex_mode) {
+    if (view->hex_mode)
+    {
         view->hex_cursor = view->dpy_start;
         view->dpy_start = mcview_offset_rounddown (view->dpy_start, view->bytes_per_line);
         view->widget.options |= W_WANT_CURSOR;
-    } else {
+    }
+    else
+    {
         view->dpy_start = view->hex_cursor;
         mcview_moveto_bol (view);
         view->widget.options &= ~W_WANT_CURSOR;
@@ -148,7 +157,8 @@ mcview_ok_to_quit (mcview_t * view)
                       _(" File was modified, Save with exit? "), D_NORMAL, 3,
                       _("&Cancel quit"), _("&Yes"), _("&No"));
 
-    switch (r) {
+    switch (r)
+    {
     case 1:
         return mcview_hexedit_save_changes (view);
     case 2:
@@ -165,7 +175,8 @@ void
 mcview_done (mcview_t * view)
 {
     /* Save current file position */
-    if (mcview_remember_file_position && view->filename != NULL) {
+    if (mcview_remember_file_position && view->filename != NULL)
+    {
         char *canon_fname;
         off_t line, col;
 
@@ -191,15 +202,25 @@ mcview_done (mcview_t * view)
     mcview_close_datasource (view);
     /* the growing buffer is freed with the datasource */
 
-    if (view->coord_cache) {
+    if (view->coord_cache)
+    {
         g_array_free (view->coord_cache, TRUE), view->coord_cache = NULL;
     }
 
-    if (!(view->converter == INVALID_CONV || view->converter != str_cnv_from_term)) {
+    if (view->converter == INVALID_CONV)
+        view->converter = str_cnv_from_term;
+
+    if (view->converter != str_cnv_from_term)
+    {
         str_close_conv (view->converter);
         view->converter = str_cnv_from_term;
     }
 
+    mc_search_free (view->search);
+    view->search = NULL;
+    g_free (view->last_search_string);
+    view->last_search_string = NULL;
+    mcview_nroff_seq_free (&view->search_nroff_seq);
     mcview_hexedit_free_change_list (view);
 }
 
@@ -213,10 +234,12 @@ mcview_set_codeset (mcview_t * view)
 
     view->utf8 = TRUE;
     cp_id = get_codepage_id (source_codepage >= 0 ? source_codepage : display_codepage);
-    if (cp_id != NULL) {
+    if (cp_id != NULL)
+    {
         GIConv conv;
         conv = str_crt_conv_from (cp_id);
-        if (conv != INVALID_CONV) {
+        if (conv != INVALID_CONV)
+        {
             if (view->converter != str_cnv_from_term)
                 str_close_conv (view->converter);
             view->converter = conv;
@@ -234,7 +257,8 @@ void
 mcview_select_encoding (mcview_t * view)
 {
 #ifdef HAVE_CHARSET
-    if (do_select_codepage ()) {
+    if (do_select_codepage ())
+    {
         mcview_set_codeset (view);
     }
 #else
@@ -248,9 +272,12 @@ void
 mcview_show_error (mcview_t * view, const char *msg)
 {
     mcview_close_datasource (view);
-    if (mcview_is_in_panel (view)) {
+    if (mcview_is_in_panel (view))
+    {
         mcview_set_datasource_string (view, msg);
-    } else {
+    }
+    else
+    {
         message (D_ERROR, MSG_ERROR, "%s", msg);
     }
 }
